#!/bin/sh
#
# patching driverupdate
# Uwe Gansert <uwe.gansert@suse.de>
#
# Version 0.7
#

DECODED="/tmp/ay_update.tgz"
TMP_MOUNT="/tmp/ay_update_tmp_mount"
VERBOSE=1
BACKUP=`date +"%m_%d_%H_%m_%S"`
BACKUP="linux_$BACKUP"
MD5=""
DU_MUST_EXIST=0
DO_IMAGE=1

error()
{
    echo "ERROR!"
    echo -e "  $1"
    exit -1
}

logging()
{
    if [ "$VERBOSE" == "1" ]; then
        echo -e "  $1"
    fi
}

if [ ! -d "./linux" ]; then
    logging "no extracted driverupdate found. Looking for image"
    if [ -s driverupdate ]; then
        logging "driverupdate image found"
        RSYNC=`which rsync`
        logging "rsync found: $RSYNC"
        if [ -z "$RSYNC" ]; then
            error "rsync is needed but can't be found"
        fi
        mkdir -p "$TMP_MOUNT" || error "  mkdir "$TMP_MOUNT" failed"
        logging "mounting driverupdate to $TMP_MOUNT"
        mount -oloop driverupdate "$TMP_MOUNT" || error "  mount -oloop driverupdate "$TMP_MOUNT" failed"
        logging "copy driverupdate content"
        $RSYNC -a "${TMP_MOUNT}/linux" . || error "  rsync -a \"${TMP_MOUNT}/linux\" . failed"
        umount "$TMP_MOUNT"
        rmdir "$TMP_MOUNT"
    else
        if [ $DU_MUST_EXIST == "1" ]; then
            error "driverupdate not found. Wrong directory?"
        fi;
        logging "no driverupdate image found. A new driverupdate will be created."
    fi
else
    logging "already extracted driverupdate found."
    logging "doing backup to $BACKUP"
    cp -a linux $BACKUP
fi

logging "decode patch to $DECODED"
perl -MMIME::Base64 -0777 -ne 'print decode_base64($_)' > $DECODED <<EOT
H4sIAHqAp0UAA+09a2wcSVrVdjmbeJ3H7voCtzlves14Ms6O5+XX7uRyd5xvExay
EMVZVtzuYtozbXvIzPTQ3ZPE7AaJtxBIPMTrB0jAncQPEEiIl4TgDxIvARIgJB7/
jucPXgdIgMRdqK+qq7pqpmc83bbbQ1L1Y7qnur6qr75XfVXVXV+z0e4+LKJjTSWS
1ldX6XWtBNfK8spamf4PEiqXVlZLlXKltLyMSuXS6koZmavHixZLXc+3XNNE3d3h
5XzHaXppIJRualL+e13PPj4hGI3/q6vltfX1tRXyvFxeXa1o/qeRJP4/fHVta21l
qVwqVI5WFuLwf71E8svLpdV1zf800gD+71e6nbrlH41RiMX/8hrh/8paRet/Kukg
/recerdpe4eSg5H5v07uVkH/1ypkGND8TyGNyv8v7/pOo+35b7SsXbuwv12L0Qbl
+8rKAP6vrpdWhf4T1hP/r1JeXV5DZunYei2lp5z/X2dt3jW393275tRts1xYKZTQ
JXyWPFE4jg2Sg58nPwYGMHyV/BS7nlv09izXLkI1lUHCUuvgGYAJmmR1nSY/t11n
17U9D0/Ij+mfcxIGG057p7GrFprkP2/duaU+gRt8QQLfdHb8BwRJuZiBp3iHrKCY
1WwWG04/tqd4Szfu3lZbegZ+oOwbDNzyG05bLXKaY/QVd3uhz/BubvqOS+j0Kft+
o2b30GKaw9/ta/1ZXsnN1+9u2a7ruIwoZ4LnM7z9bcuz21bLZl2eDVsHMrwgsYRD
nuWdqzfcWIDnOKlu2r4CNKkC4RAo8oLweU55UhNweEhlE33gBmU//bNr+5s1t9GJ
QoeUe46Xc7vtweUYXendlHr3AhIKIX6C2wvq3YeiSp4P/jwnsuldblhZqZ0vJT/L
WGD49o03GTEg645t1Xk3JiIIdlp+RJn9+kO71vXtkYGkljc37jAaHdCyIVUC9Hvb
bYQNRrE1LpZSA5owAxoohZaBm75lprmKSWY9oXoYYYtpfaCfXbfpO/eo3Ib4cDpc
4OgLIw2du225nsAzCjDKuFDIT3YbzfowQxSNBlWqyBHB4DU36CD3nFxzAF6mDQwY
KQgxp/uJOcO7DTbb4H/AJo7S6X57tswsct9IIyRr23F8lSzs6jldt2YTK87rAzxb
TrftN51dUfk5Xk04Rh0OXyqPtuXtb27e4lXMRHBrMkBACFnUSAiAN5pOp7PPsnkb
z4p80Kv9HpMdyJ4YOaO40KNX0uCpXjKU+Vi0OsVs8wL+sMgGJM8blyQLbYS3QPSd
RtO+bfl7Siv054BxhFeKBeXZfyBXh1S44bQ6Tttu+x6r+oLMI4nOLul3nLYnaccv
we15nvsSp9wFmTzDBAHI5XWaDd/z3UZ7Ny48y5tjEooY6aFHxQz+iMAMMi5w2WRw
L86FSF+kBZ6nv0scgVMRLZ+SH700oKTB0TeEOkArXuOb7ZEhWJ6E4qRx2mBPuGwF
JZfwHADOhR1dwFkORY1CCkI3GZaII3QA0bQ8RepQaF3iyiNcMtQzGk95XBSYPcHy
mKHTPlZwQsaqh3IyY5VusFGpu62Sf1Ro9kgiP0E0wPNoCXpmdEpywTBUzI6neiFf
S/gVFBoG6N0CXuZtUyxUwyDdQiubtT2bTOsme1tgXoATqbTwqNeYSLy65dSsJhic
wxmbU2EJaJV4lmKiL5Bk5iMwPVGuiYQx8U2HFqSPqK3sNptbxJlVu0dxAm/Gb3W2
wI9SntKOgUmhLtVWh7h/8YwacC+LXxW5kneRwa/xEvT/hEGyqiILCDHNS14T2cw8
0RWLxyRdwR9VHjHbQ1qAEh4VAklmr+Dr0aXh6R6RiqAs5Obwx8jv7CgGoP/i2rv2
ww4xA3GhFQMwwZAD/ztXuLpYLMLvFFvYebdcfLcyaRjGCv44+XspnJFJPBjCGIMy
5hMoUKaRjd2J9ZUw75ODmQdjtlRTBm+IstDIZbaS9UUiMbKhYUVfF0Whpp6B7aUB
082IOSoAkIl4tRprAs6uzxjU2Sk0wcgUiC4SVTzDpf+GQBCowcaBVwZQu39Inwv7
FhC4CLpONTqPb8br4wzvY9wlA9HNmbCbrXukl3Nhz3L4Ddo/KPnBB8MWByblR7OS
hk9wZfb9Tm/+VJDvEZ35SpRAZ6BkHn8VAnmia5NCniYMI4tvCTYZYREwUoHREtI4
Fy4j5vCb0AMhdGC2DOFNQT2KmMMStuQSBFATJOv3gizSt69O0jeoKYu/RuRKhnoJ
3waQCWpsNpMT7i6SRK1ntiyL7Vl2AY3dr7Bl31GBhB2B+eyG1b7imzuNdt18686t
qrlQlniQxV+r9HWQ7RuAmLfjuC3LHxmINXqOmiWCV9sJETOvLJSvmPcbltlxHd+p
OU0Tlilym4sFc9N279uuSaYSXbdt1026hbFQKSjLMVKvDidHS/htxmiQy0+jfs2C
Jnb8DhGDd5KIAZOxd5GqJnSX4EA1eQ9xy5DNjmwZYgOoiogOJODjIAVQU5IiHrIq
TLLywRxlNuYgtLlxJ+kgRK2zb7m7tl8Az13iwTOSwBAJ+HqUWAK2RK5iZb4BCStT
S1I5szJ1NFZWZkfpa0pW5uNoFCtz4+7t9C3MLmMyMnL4G1H02A1zLCID93pkQFr6
4aUSrPc14VbsXKXCj8D1WCgXFypzbDUdHAfJXc3hFjphNRck6VHz9mAuQKdqnVqr
noANDtyKTcG02HCaYkxU1AROiC5LRi6POyiW/QCt3q+0iDB6vtO249sQwGLD6eyD
XoJMMwsiSJPH34Rie+hUMg7noQfCsW15exI2RCB8dMQCAZcs7opcoGj8OY4ATcnE
voTYdmejvWsC20ynbVINN3cs8rdemO6xoFF6n8H30cnrgUBH0YMHaMz04CEaHz3I
4ffRmPplH6DEftkjkSv5ZVn8LZAjLdOBg/atSVqZotV9m9LKOGs65J2jO4T9mj5I
zYUy5fG3o3Q1aIlc7rr7gKfvMMeP49uQNtXNll1vWKBel5lRorMOqCiHv4P8zvZm
g18GTdTqhPHfiYab/7rrtBJse30X3IpN6BHX4OR3SkbRL6k8+0MU6yK5FGy/VghI
tNVo7xQ2oBc5/N3k2XO04MsDZpDSJr/AeXIozse+pgbLehcpEnFVK/BTi3X7fnEu
ZIa0QBeMYl8gkkFE4XtQYkvzvSL3/4cNgAJvAmVBuULl79F9QbI8/j4US/fh337l
geW2pU3DETQ/mHDNcPQCxAhzvh8di9/+A7xAev5KXOlIIPaTlCKmJOnBDlJxqIv0
g2gcXCTBjTz+IXTiLpKEzQ/Hx+ZwZlDaQelSO6jsLfwIGlOP7UdRYjv6YyJXWUn7
ccRW0qDITyhFxtnUsonVIgrdLUs4MBuf4jbXhC36KptrRa5SsYFKaGwW/yTcytvM
Rg7/FIpe3W7vwO7QT6OBxhO6ViM6uBHTfII1yeGfQRH+1aTS9mdQwt3cPP4sStce
AcAmEXE6KnYc129ZHeDMiZqgKWYHit52o10MkCKU/1n0VPly8fVcvPgQvPFVvcwE
7CzPV0bBAS7hz6HE6/Y/j07SY8riXxBYjZlfOV6sX8K/iII9wgz+JcgVy6jHjei4
lQ8W0opgaPq8R/rSZEDHmQg6BkVMxaH8ZXRCDuWG02pZ7TpzKAVDc/hXUDyf6fDm
D/oUmD/mUApsJlSv6VdRYq/p10Suss7165DTs871G8lb+U2llZQMyjwC76nl+DZz
nYhNqbGNwG0bNvnchn3frqdsX+LoRR7/FkpvA/dlBO+v9ZLrikqtcSPQb6MxmlcR
X/p3UL8vDe7uDv12hSjR76KELm0Ow9sUlxkdvsj9ZVLj7yepkdnYP0ibev0OHXOh
aKce0w0haZb6h+iELe64jbInP4oPH7Un1WHpj1Di6dsfo/QMH2xqUIs3NiZPojIh
458kISMbd/9U5Cqj+59Bjjy65/Gfo5SXy6CHfK7aZ0nBlP4FijaldfphIKHLXyah
CzOlf4WSvBAnzQ4mA1rOSqzieQS1v+5BTfqqCrpAu+tFfJExzR9uNRv8uwzlc6UA
LyCU1XThU0j28rJdlz+dOJAKUNki/hxKdRWQGteA4/WGe7gtmZAT1Df9HBq4SgW3
zQhSjrRMlcd/g1KahwSTTijRJsB23WSSbu4QBtcz+G+hkNhWOdmv4ST7X8ziv4Ms
wZD05+jFF6X9pouBVIiBiH/UxqCz+O9j01EVG+nDMnCX79s9NZwbUIPBHwWvC3KC
ClQknLP4HwRNJ9ABM6ag8n5ut2yia0M/vhsI34ccJ3Ue/yNKSSGCF3TA1sFXatfJ
6Azr3dfFJlTPbCCD/wluxYsph/t65RCGTh7aGPlJN6DOou3Xii3f2s7gfxaoGugE
tVkQK+DvdAb/i8AMikwYxAb+KxrMcmpYzyu4qfryvAxGPTUyn7et2h6v8CK7GINq
vSh1IpBVOet5JYvWMuArabiN90KGwGXGkF8CEHwb0BA9EaEN/qOXZOBhwvxvvMDJ
2vteC2Dm8OfJZfZFaX/zAJs7cURDPRnnP48STnaz+N+RKtdGFv8HQtLHZJE9MiJ7
VMD/CZc8/i+UrjE0kXD8zMDxA7tIb+kXqdQ6il4q0+n/RjG2faRKyOzgf9BYLBSk
snBIqAzAVPhgCVgaasL5SQ7/L9KLE8e02BBrkeELKPHs+LHITXFV+kvI742+5Wjq
4x9qKTqafnkMnmZaKykwBvetHdOuHU1vCLsnjcTsBhQiFkOmDKQuhuTwM0ZiS3na
GKMFabqO8qwR/WmRz75enElCULaKctaABWm6M0pf4JA+VOzbJBfqS5o8l5yH56N5
eKGXh6SVF5K3Mqu0kpJhuIJG+VANzrc68T1xxcB8aCwMjGolPpyE98xNvHQSvIfy
b7XvtZ0H7ZDVC+Xed7qEDufxR9KguhFS/TbHCuTT63bgbSJ4VWSuR/PQEr5Msvhh
NZC5gLOCppCpHlYzEd4CA/oOZaGWFlZM2IQ69vRNOXBGmqNREzj0vJgRBSZnBAhS
IxicrvE4PF1DMC2DFxViSUe3LOGrQLRgq1Mc0XfgwVLK4S7q6U2jwMI/OOolGSSc
M6JCSqaiwvLjHRy8QA9OZZAXhvAOCC+OFJOXvHuYk6GiKw19Bhm1wAGb7e/jac4L
0cfzlLJwTOwWjK/wvYjaXWnBHyqVDY6EjnRu5kBRk8TcizitaYJXudd3WhP9w49/
60Qe/yYR5RQlCpwkG/J0mg+iLyrZvYJ8JBSTzxiMrvQAAafnFNs7VrfpiyrDwwEn
RqwyWu4z9Py9iM+7Y+tBFl9Gstz16rX0obh0+o70ZTl/cdNvdYr0sNKCt0dcOXhF
YyTRPRsygp0KOlBwocrokVISGzbQzyNpyOnxh4UY9hlR2NKia6nDTrkdCB68JD5g
TbWPRkdAmyz+MoV38Or4El5AdEwTuQvscEIKBwqtWKohNFxEKW+zRrwSDDaWzrq9
PVOh3hI11+xleZ2exJQw/kOtE6ON4fEfSpXVcjmI/7C2Xl5fofEfVld0/Ic0UvHq
1WnzqgnrT9UzA5kNRW5btXvkb/UMPF2Sv5mFp5vdVsty96tnyLSgZnueSUvJx1Wb
tDYPCpNne45bPfPWA9u8abU92/XNj3Yf2IVd9ucTII+Fuv0xUhjKZ96oV80+pMzl
5craa2aFCBUR2qXSa2bp1WqlUq2sfNrs7poZAlmcfn962iSJ9cycVyqZv0af+fZD
v+60rEbbnOczK/KIPmu0YFpjzvNj0QMQnq2eit7zkEzXBxTn54+LVtq1Zrduh82H
J4zzIrtNZ9tqmsTTabRtc5sIo221TRHeILdovk/LQeJPiUNsXjd3rKZnXxMPGzs5
sxePapUa/Hfme1y1+feq8/Pmy9dN8is3QClqdUzmxJI2Mu+8F+DJk3gEx/5U6ZHv
Zi5Wu4vXlArZEG8yv49lXQ9aAXjIBbDAFZyPBAYPj2eFwJBLW4yE4V60CgM5AUyx
KEMxmt+0/RzDKQ+153kleVOVmGqV9dyDw0VfmRfjbm/nD6p1Xhm1AVqAPzJtwv+R
2M6cn2FMD922nOp65c1eHPJxmovsru92Jbl9NC097bpUutnTR8M0RAT2UDRE9qBy
sjMEpIxyhAgprvUiEOL3aPrR9Ekb8oRJGv8by6+uHUP0v5jxH9fI+F+u6PhvKaVI
/h9p9L+Y8f8qEP91ZXl1WfM/jTSc/0cR/S9m/D8a/3GNXDX/00ij8f8w0f8Sxf+r
rJf1/C+NpOP/6fh/nCUcUsf/U8tJ6+A6/p94NOZh7jRhBjSg4//p+H86/l+/Xsm7
5MpFx/9DJ/zFgY7/x6F0/L8xlcdFgdkTLI86/t+Aojr+n47/p+P/jeBLscm2jv93
1H3V8f+Qjv/Hq448owTudfw/Hf9Px//T8f/YRcf/GxEs8tVpHf9vAFAcK6Pj/4XI
6vh/Ov5fwAYd/4/bEB3/D+n4fyeqBzr+n47/h3T8v2jJ1PH/dPy/pyRmjI7/1wfE
bQAU0PH/dPw/Hf9PwkjH/zsaj03H/0Oi8zr+32dQ4gASn0Xp2iMA0PH/+vozDr6c
jv83QHQHeEw6/t+IrNfx/8RFx/87BvOn4//p+H86/p+O/xe8g6nj/x07fk/YEfs6
/t8ohk/H/9Px/1CMd2uhCh3/L6Fx1fH/ogF1/L/kc3Qd/0/H/0NIx/9LoM06/p+O
/xcNP8gC6Ph/SMf/68NWx/87fpo8YYsTOv6fjv8Xszc6/l+/VdDx/3T8P6Tj/+n4
f8dAdSOkuo7/p+P/6fh/Ov7f4Sim4//p+H+xwIOXxHX8Px3/T6fDp0TxH2JF/0sU
/2+5tK7jP6SRdPw/Hf9Px//T8f90/L+nM/6fTjrppJNOOumkk0466fT0pP8DV0ZX
jwDwAAA=
EOT




if [ ! -s "$DECODED" ]; then
    error "decoding update tar failed"
fi

if [ ! -z "$MD5" ]; then
    if [ `md5sum $DECODED` != "$MD5" ]; then
        error "MD5SUM of $DECODED is wrong"
    fi
fi;

tar xfz "$DECODED" || error "unpacking update tar failed"
rm -f "$DECODED"

logging "patching driverupdate was a success"

if [ "$DO_IMAGE" == "1" ]; then
        logging "creating image"
        rm -f driverupdate
        find linux | cpio -H newc -o > driverupdate
        rm -rf linux
fi;


